==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fNew.h <==
// class soot.coffi.Instruction_New

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 21e7a39d58747310 soot_coffi_Instruction__5fNew
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fNew_H_
#define _JC_soot_coffi_Instruction__5fNew_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fNew$sub_refs	_jc_soot_coffi_Instruction__5fNew$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fNew$sub_nonrefs	_jc_soot_coffi_Instruction__5fNew$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fNew$refs	_jc_soot_coffi_Instruction__5fNew$refs;
typedef struct _jc_soot_coffi_Instruction__5fNew$nonrefs	_jc_soot_coffi_Instruction__5fNew$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fNew$object	_jc_soot_coffi_Instruction__5fNew$object;

typedef const struct _jc_soot_coffi_Instruction__5fNew$vmethods	_jc_soot_coffi_Instruction__5fNew$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fNew$vtable	_jc_soot_coffi_Instruction__5fNew$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fNew$vtype	_jc_soot_coffi_Instruction__5fNew$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fNew$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fNew$object *);

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fNew$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fNew$object *, struct _jc_soot_coffi_Instruction$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fNew$method_info$branchpoints$0387b0529fae51a0;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fNew$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNew$object *, struct _jc_soot_coffi_Instruction$object *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fNew$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fNew$vmethods	soot_coffi_Instruction__5fNew;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fNew$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fNew$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fNew$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fNew$refs {
    _jc_soot_coffi_Instruction__5fNew$sub_refs	soot_coffi_Instruction__5fNew;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fNew$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fNew$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fNew$sub_nonrefs	soot_coffi_Instruction__5fNew;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fNew$object {
	_jc_soot_coffi_Instruction__5fNew$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fNew$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fNew$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fNew$vtype _jc_soot_coffi_Instruction__5fNew$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fNew, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fNew$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fNew_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fNew.h <==
// class soot.coffi.Instruction_New

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 21e7a39d58747310 soot_coffi_Instruction__5fNew
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fNew_H_
#define _JC_soot_coffi_Instruction__5fNew_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fNew$sub_refs	_jc_soot_coffi_Instruction__5fNew$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fNew$sub_nonrefs	_jc_soot_coffi_Instruction__5fNew$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fNew$refs	_jc_soot_coffi_Instruction__5fNew$refs;
typedef struct _jc_soot_coffi_Instruction__5fNew$nonrefs	_jc_soot_coffi_Instruction__5fNew$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fNew$object	_jc_soot_coffi_Instruction__5fNew$object;

typedef const struct _jc_soot_coffi_Instruction__5fNew$vmethods	_jc_soot_coffi_Instruction__5fNew$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fNew$vtable	_jc_soot_coffi_Instruction__5fNew$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fNew$vtype	_jc_soot_coffi_Instruction__5fNew$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fNew$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fNew$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fNew$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fNew$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fNew$method_info$branchpoints$0387b0529fae51a0;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fNew$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNew$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fNew$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fNew$vmethods	soot_coffi_Instruction__5fNew;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fNew$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fNew$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fNew$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fNew$refs {
    _jc_soot_coffi_Instruction__5fNew$sub_refs	soot_coffi_Instruction__5fNew;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fNew$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fNew$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fNew$sub_nonrefs	soot_coffi_Instruction__5fNew;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fNew$object {
	_jc_soot_coffi_Instruction__5fNew$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fNew$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fNew$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fNew$vtype _jc_soot_coffi_Instruction__5fNew$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fNew, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fNew$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fNew_H_ */
